@@ -452,11 +452,11 @@ GSList *
 gnomemeeting_local_addressbook_get_contacts (GmAddressbook *addb,
 					     int & nbr,
 					     gboolean partial_match,
-					     gchar *fullname,
-					     gchar *url,
-					     gchar *categorie,
-					     gchar *location,
-					     gchar *speeddial)
+					     const gchar *fullname,
+					     const gchar *url,
+					     const gchar *categorie,
+					     const gchar *location,
+					     const gchar *speeddial)
 {
   gchar *key = NULL;
   gint aid = 0;
