@@ -60,57 +60,22 @@
 
 #define new PNEW
 
-GMSignalFilter::GMSignalFilter ()
-: receiveHandler (PCREATE_NOTIFIER (ReceivedPacket)),
-  sendHandler (PCREATE_NOTIFIER (SentPacket))
-{
-  main_window = GnomeMeeting::Process ()->GetMainWindow ();
-}
-
-
-void GMSignalFilter::ReceivedPacket (RTP_DataFrame & frame,
-				     INT unused)
-{
-  // Silent
-  if (frame.GetPayloadSize() == 0)
-    return;
-
-  float input = GMAudioRP::GetAverageSignalLevel ((const short *) frame.GetPayloadPtr (), frame.GetPayloadSize ());
-  
-  gnomemeeting_threads_enter ();
-  gm_main_window_set_signal_levels (main_window, -1, input);
-  gnomemeeting_threads_leave ();
-}
-
-
-void GMSignalFilter::SentPacket (RTP_DataFrame & frame,
-				 INT unused)
-{
-  // Silent
-  if (frame.GetPayloadSize() == 0)
-    return;
-  
-  float output = GMAudioRP::GetAverageSignalLevel ((const short *) frame.GetPayloadPtr (), frame.GetPayloadSize ());
-
-  gnomemeeting_threads_enter ();
-  gm_main_window_set_signal_levels (main_window, output, -1);
-  gnomemeeting_threads_leave ();
-}
-
-
 GMPCSSEndpoint::GMPCSSEndpoint (GMManager & ep) 
 : OpalPCSSEndPoint (ep), endpoint (ep)
 {
   CallPendingTimer.SetNotifier (PCREATE_NOTIFIER (OnCallPending));
   OutgoingCallTimer.SetNotifier (PCREATE_NOTIFIER (OnOutgoingCall));
 
-  signal_filter = new GMSignalFilter ();
+#ifdef WIN32
+  SetSoundChannelBufferDepth (20);
+#else
+  SetSoundChannelBufferDepth (5);
+#endif
 }
 
 
 GMPCSSEndpoint::~GMPCSSEndpoint () 
 {
-  delete signal_filter;
 }
 
 
@@ -119,16 +84,7 @@ GMPCSSEndpoint::MakeConnection (OpalCall & call,
                                 const PString & party,  
                                 void * userData)
 {
-  BOOL result = FALSE;
-  
-  OutgoingCallTimer.RunContinuous (PTimeInterval (5));
-  
-  result = OpalPCSSEndPoint::MakeConnection (call, party, userData);
-
-  if (!result)
-    OutgoingCallTimer.Stop ();
-
-  return result;
+  return OpalPCSSEndPoint::MakeConnection (call, party, userData);
 }
 
 
@@ -180,6 +136,9 @@ void GMPCSSEndpoint::OnShowIncoming (const OpalPCSSConnection & connection)
 
 BOOL GMPCSSEndpoint::OnShowOutgoing (const OpalPCSSConnection & connection)
 {
+  if (endpoint.GetCallingState () == GMManager::Calling)
+    OutgoingCallTimer.RunContinuous (PTimeInterval (5));
+
   return TRUE;
 }
 
@@ -198,6 +157,7 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
 				    const OpalMediaFormat & format,
 				    BOOL is_source)
 {
+  PTRACE(3, "Ekiga\tCreating Sound Channel");
   GtkWidget *main_window = NULL;
   GtkWidget *history_window = NULL;
   GtkWidget *statusicon = NULL;
@@ -250,7 +210,6 @@ GMPCSSEndpoint::CreateSoundChannel (const OpalPCSSConnection & connection,
 
       
       /* Update the volume sliders */
-      //FIXME popups
       if (is_source) 
 	sound_channel->GetVolume (record_vol);
       else 
@@ -340,18 +299,6 @@ GMPCSSEndpoint::OnGetDestination (const OpalPCSSConnection &connection)
 }
 
 
-void 
-GMPCSSEndpoint::OnPatchMediaStream (const OpalPCSSConnection & connection, 
-				    BOOL is_source,
-				    OpalMediaPatch & patch)
-{
-  OpalPCSSEndPoint::OnPatchMediaStream (connection, is_source, patch);
-
-  if (patch.GetSource().GetSessionID() == OpalMediaFormat::DefaultAudioSessionID) 
-    patch.AddFilter(is_source ? signal_filter->GetReceiveHandler() : signal_filter->GetSendHandler(), OpalPCM16);
-}
-
-
 void 
 GMPCSSEndpoint::GetDeviceVolume (unsigned int &play_vol,
 				 unsigned int &record_vol)
