@@ -67,9 +67,9 @@
 
 
 /* Declarations */
-static void applicability_check_nt (gpointer,
-				    GmConfEntry *,
-				    gpointer);
+static void applicability_check_nt (gpointer id,
+				    GmConfEntry *entry,
+				    gpointer data);
 
 
 /* DESCRIPTION  :  This callback is called when the control panel 
@@ -80,9 +80,9 @@ static void applicability_check_nt (gpointer,
  *                 to the FULLVIEW view.
  * PRE          :  /
  */
-static void control_panel_section_changed_nt (gpointer, 
-                                              GmConfEntry *, 
-                                              gpointer);
+static void control_panel_section_changed_nt (gpointer id,
+                                              GmConfEntry *entry,
+                                              gpointer data);
 
 
 /* DESCRIPTION  :  This callback is called when the view mode 
@@ -90,9 +90,9 @@ static void control_panel_section_changed_nt (gpointer,
  * BEHAVIOR     :  Shows/hides components and updates the UI.
  * PRE          :  The main window GMObject. 
  */
-static void view_mode_changed_nt (gpointer, 
-					   GmConfEntry *, 
-					   gpointer);
+static void view_mode_changed_nt (gpointer id,
+				  GmConfEntry *entry,
+				  gpointer data);
 
 
 /* DESCRIPTION  :  This callback is called when the firstname or last name
@@ -101,112 +101,111 @@ static void view_mode_changed_nt (gpointer,
  * 		   main endpoint configuration.
  * PRE          :  /
  */
-static void fullname_changed_nt (gpointer, 
-				 GmConfEntry *, 
-				 gpointer);
+static void fullname_changed_nt (gpointer id,
+				 GmConfEntry *entry,
+				 gpointer data);
 
-static void video_media_format_changed_nt (gpointer, 
-					   GmConfEntry *, 
-					   gpointer);
+static void h245_tunneling_changed_nt (gpointer id,
+				       GmConfEntry *entry,
+				       gpointer data);
 
-static void jitter_buffer_changed_nt (gpointer, 
-                                      GmConfEntry *, 
-				      gpointer);
+static void early_h245_changed_nt (gpointer id,
+				   GmConfEntry *entry,
+				   gpointer data);
+
+static void fast_start_changed_nt (gpointer id,
+				   GmConfEntry *enty,
+				   gpointer data);
+
+static void outbound_proxy_changed_nt (gpointer id,
+				       GmConfEntry *entry,
+				       gpointer data);
+
+static void enable_video_changed_nt (gpointer id,
+				     GmConfEntry *entry,
+				     gpointer data);
+
+static void silence_detection_changed_nt (gpointer id,
+					  GmConfEntry *entry,
+                                          gpointer data);
+
+static void echo_cancelation_changed_nt (gpointer id,
+					 GmConfEntry *entry,
+					 gpointer data);
+
+static void capabilities_changed_nt (gpointer id,
+				     GmConfEntry *entry,
+                                     gpointer data);
+
+static void video_media_format_changed_nt (gpointer id,
+					   GmConfEntry *entry,
+					   gpointer data);
+
+static void jitter_buffer_changed_nt (gpointer id,
+                                      GmConfEntry *entry,
+				      gpointer data);
+
+static void accounts_list_changed_nt (gpointer id,
+				      GmConfEntry *entry,
+				      gpointer data);
+
+static void interface_changed_nt (gpointer id,
+				  GmConfEntry *entry,
+				  gpointer data);
+
+static void public_ip_changed_nt (gpointer id,
+				  GmConfEntry *entry,
+				  gpointer data);
+
+static void manager_changed_nt (gpointer id,
+				GmConfEntry *entry,
+				gpointer data);
+
+static void audio_device_changed_nt (gpointer id,
+				     GmConfEntry *entry, 
+				     gpointer data);
+
+static void video_device_changed_nt (gpointer id,
+				     GmConfEntry *entry,
+				     gpointer data);
+
+static void video_device_setting_changed_nt (gpointer id,
+					     GmConfEntry *entry,
+					     gpointer data);
+
+static void video_preview_changed_nt (gpointer id,
+                                      GmConfEntry *entry,
+				      gpointer data);
+
+static void sound_events_list_changed_nt (gpointer id,
+					  GmConfEntry *entry,
+					  gpointer data);
+
+static void audio_codecs_list_changed_nt (gpointer id,
+                                          GmConfEntry *entry,
+					  gpointer data);
+
+static void call_forwarding_changed_nt (gpointer id,
+					GmConfEntry *entry,
+					gpointer data);
 
 #if 0
-static void ils_option_changed_nt (gpointer, 
-                                   GmConfEntry *, 
-                                   gpointer);
+static void ils_option_changed_nt (gpointer id,
+                                   GmConfEntry *entry,
+                                   gpointer data);
 #endif 
 
-static void stay_on_top_changed_nt (gpointer, 
-				    GmConfEntry *, 
-                                    gpointer);
+static void incoming_call_mode_changed_nt (gpointer id,
+					   GmConfEntry *entry,
+					   gpointer data);
 
-static void incoming_call_mode_changed_nt (gpointer, 
-					   GmConfEntry *,
-					   gpointer);
+static void stay_on_top_changed_nt (gpointer id,
+				    GmConfEntry *entry,
+                                    gpointer data);
 
-static void call_forwarding_changed_nt (gpointer,
-					GmConfEntry *, 
-					gpointer);
-
-static void accounts_list_changed_nt (gpointer,
-				      GmConfEntry *, 
-				      gpointer);
-
-static void interface_changed_nt (gpointer,
-				  GmConfEntry *, 
-				  gpointer);
-
-static void public_ip_changed_nt (gpointer,
-				  GmConfEntry *, 
-				  gpointer);
-
-static void manager_changed_nt (gpointer,
-				GmConfEntry *, 
-				gpointer);
-
-static void audio_device_changed_nt (gpointer,
-				     GmConfEntry *, 
-				     gpointer);
-
-static void video_device_changed_nt (gpointer, 
-				     GmConfEntry *, 
-				     gpointer);
-
-static void video_device_setting_changed_nt (gpointer, 
-					     GmConfEntry *, 
-					     gpointer);
-
-static void video_preview_changed_nt (gpointer, 
-                                      GmConfEntry *, 
-				      gpointer);
-
-static void sound_events_list_changed_nt (gpointer,
-					  GmConfEntry *, 
-					  gpointer);
-
-static void audio_codecs_list_changed_nt (gpointer, 
-                                          GmConfEntry *, 
-					  gpointer);
-
-
-static void capabilities_changed_nt (gpointer, 
-				     GmConfEntry *, 
-                                     gpointer);
-
-static void h245_tunneling_changed_nt (gpointer,
-				       GmConfEntry *,
-				       gpointer);
-
-static void early_h245_changed_nt (gpointer,
-				   GmConfEntry *,
-				   gpointer);
-
-static void fast_start_changed_nt (gpointer,
-				   GmConfEntry *,
-				   gpointer);
-
-static void outbound_proxy_changed_nt (gpointer,
-				       GmConfEntry *,
-				       gpointer);
-
-static void enable_video_changed_nt (gpointer, 
-				     GmConfEntry *, 
-				     gpointer);
-
-static void silence_detection_changed_nt (gpointer, 
-					  GmConfEntry *, 
-                                          gpointer);
-
-static void echo_cancelation_changed_nt (gpointer, 
-					 GmConfEntry *, 
-					 gpointer);
-
-static void network_settings_changed_nt (gpointer, 
-					 GmConfEntry *,
-                                         gpointer);
+static void network_settings_changed_nt (gpointer id,
+					 GmConfEntry *entry,
+                                         gpointer data);
 
 
 /* DESCRIPTION  :  /
@@ -926,7 +925,6 @@ video_device_setting_changed_nt (gpointer id,
 
   ep = GnomeMeeting::Process ()->GetManager ();
 
-
   if ((gm_conf_entry_get_type (entry) == GM_CONF_STRING) ||
       (gm_conf_entry_get_type (entry) == GM_CONF_INT)) {
     
@@ -1231,30 +1229,36 @@ network_settings_changed_nt (gpointer id,
 
 /* The functions */
 gboolean 
-gnomemeeting_conf_init ()
+gnomemeeting_conf_check ()
 {
-  GtkWidget *main_window = NULL;
-  GtkWidget *prefs_window = NULL;
-  GtkWidget *statusicon = NULL;
-  
   int conf_test = -1;
   
-  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow ();
-  statusicon = GnomeMeeting::Process ()->GetStatusicon ();
-  main_window = GnomeMeeting::Process ()->GetMainWindow ();
-
-
-  /* Start listeners */
-  gm_conf_watch ();
-
-    
   /* Check the config is ok */
   conf_test = gm_conf_get_int (GENERAL_KEY "gconf_test_age");
   
   if (conf_test != SCHEMA_AGE) 
     return FALSE;
 
+  return TRUE;
+}
 
+
+void
+gnomemeeting_conf_init ()
+{
+  GtkWidget *main_window = NULL;
+  GtkWidget *prefs_window = NULL;
+  GtkWidget *statusicon = NULL;
+  
+  prefs_window = GnomeMeeting::Process ()->GetPrefsWindow ();
+  statusicon = GnomeMeeting::Process ()->GetStatusicon ();
+  main_window = GnomeMeeting::Process ()->GetMainWindow ();
+
+
+  /* Init gm_conf */
+  gm_conf_watch ();
+
+    
   /* There are in general 2 notifiers to attach to each widget :
    * - the notifier that will update the widget itself to the new key,
    *   that one is attached when creating the widget.
@@ -1348,9 +1352,9 @@ gnomemeeting_conf_init ()
   gm_conf_notifier_add (SIP_KEY "default_proxy",
 			applicability_check_nt, prefs_window);
 
-  gm_conf_notifier_add (H323_KEY "dtmf_mode",
+  gm_conf_notifier_add (SIP_KEY "dtmf_mode",
 			capabilities_changed_nt, NULL);
-  gm_conf_notifier_add (H323_KEY "dtmf_mode",
+  gm_conf_notifier_add (SIP_KEY "dtmf_mode",
 			applicability_check_nt, prefs_window);
 
   
@@ -1456,6 +1460,12 @@ gnomemeeting_conf_init ()
   gm_conf_notifier_add (SOUND_EVENTS_KEY "new_voicemail_sound",
 			sound_events_list_changed_nt, prefs_window);
 
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "enable_new_message_sound",
+			sound_events_list_changed_nt, prefs_window);
+
+  gm_conf_notifier_add (SOUND_EVENTS_KEY "new_message_sound",
+			sound_events_list_changed_nt, prefs_window);
+
  
   /* Notifiers for the AUDIO_CODECS_KEY keys */
   gm_conf_notifier_add (AUDIO_CODECS_KEY "list", 
@@ -1507,9 +1517,6 @@ gnomemeeting_conf_init ()
 			capabilities_changed_nt, NULL);
   gm_conf_notifier_add (VIDEO_CODECS_KEY "transmitted_video_quality", 
 			network_settings_changed_nt, NULL);
-
-
-  return TRUE;
 }
 
 
@@ -1525,37 +1532,40 @@ gnomemeeting_conf_upgrade ()
   /* Install the sip:, h323: and callto: GNOME URL Handlers */
   conf_url = gm_conf_get_string ("/desktop/gnome/url-handlers/callto/command");
 					       
-  if (!conf_url) {
-    
+  if (!conf_url 
+      || !strcmp (conf_url, "gnomemeeting -c \"%s\"")) {
+
     gm_conf_set_string ("/desktop/gnome/url-handlers/callto/command", 
-			"ekiga -c \"%s\"");
+                        "ekiga -c \"%s\"");
+
+    gm_conf_set_bool ("/desktop/gnome/url-handlers/callto/needs_terminal", 
+                      false);
 
-    gm_conf_set_bool ("/desktop/gnome/url-handlers/callto/need-terminal", 
-		      false);
-    
     gm_conf_set_bool ("/desktop/gnome/url-handlers/callto/enabled", true);
   }
   g_free (conf_url);
 
   conf_url = gm_conf_get_string ("/desktop/gnome/url-handlers/h323/command");
-  if (!conf_url) {
-    
+  if (!conf_url 
+      || !strcmp (conf_url, "gnomemeeting -c \"%s\"")) {
+
     gm_conf_set_string ("/desktop/gnome/url-handlers/h323/command", 
-			"ekiga -c \"%s\"");
-    
-    gm_conf_set_bool ("/desktop/gnome/url-handlers/h323/need-terminal", false);
+                        "ekiga -c \"%s\"");
+
+    gm_conf_set_bool ("/desktop/gnome/url-handlers/h323/needs_terminal", false);
 
     gm_conf_set_bool ("/desktop/gnome/url-handlers/h323/enabled", true);
   }
   g_free (conf_url);
-  
+
   conf_url = gm_conf_get_string ("/desktop/gnome/url-handlers/sip/command");
-  if (!conf_url) {
-    
+  if (!conf_url 
+      || !strcmp (conf_url, "gnomemeeting -c \"%s\"")) {
+
     gm_conf_set_string ("/desktop/gnome/url-handlers/sip/command", 
 			"ekiga -c \"%s\"");
     
-    gm_conf_set_bool ("/desktop/gnome/url-handlers/sip/need-terminal", false);
+    gm_conf_set_bool ("/desktop/gnome/url-handlers/sip/needs_terminal", false);
 
     gm_conf_set_bool ("/desktop/gnome/url-handlers/sip/enabled", true);
   }
@@ -1564,6 +1574,6 @@ gnomemeeting_conf_upgrade ()
   conf_url = gm_conf_get_string (NAT_KEY "public_ip_detector");
   if (conf_url && !strcmp (conf_url, "http://213.193.144.104/ip/"))
     gm_conf_set_string (NAT_KEY "public_ip_detector", 
-			"http://gnomemeeting.net/ip/");
+			"http://ekiga.net/ip/");
   g_free (conf_url);
 }
